==> haskell-unordered-containers-0.2.12.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unordered-containers
version:              0.2.12.0
visibility:           public
id:                   unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
key:                  unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
license:              BSD-3-Clause
copyright:
    2010-2014 Johan Tibell
    2010 Edward Z. Yang

maintainer:           johan.tibell@gmail.com, David.Feuer@gmail.com
author:               Johan Tibell
homepage:
    https://github.com/haskell-unordered-containers/unordered-containers

synopsis:             Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.

    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.

category:             Data
abi:                  7f25bd315a1dce348591e963f8e30b20
exposed:              True
exposed-modules:
    Data.HashMap.Internal Data.HashMap.Internal.Array
    Data.HashMap.Internal.List Data.HashMap.Internal.Strict
    Data.HashMap.Internal.Unsafe Data.HashMap.Lazy Data.HashMap.Strict
    Data.HashSet Data.HashSet.Internal

import-dirs:
    /usr/lib/ghc-8.10.2/site-local/unordered-containers-0.2.12.0

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/unordered-containers-0.2.12.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/unordered-containers-0.2.12.0

hs-libraries:         HSunordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
depends:
    base-4.14.1.0 deepseq-1.4.4.0
    hashable-1.3.0.0-JGLlBEJENIuAu5I6ebR7jm

haddock-interfaces:
    /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.12.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unordered-containers
version:              0.2.12.0
visibility:           public
id:                   unordered-containers-0.2.12.0-JMHeBencosjFi5kYThmmhW
key:                  unordered-containers-0.2.12.0-JMHeBencosjFi5kYThmmhW
license:              BSD-3-Clause
copyright:
    2010-2014 Johan Tibell
    2010 Edward Z. Yang

maintainer:           johan.tibell@gmail.com, David.Feuer@gmail.com
author:               Johan Tibell
homepage:
    https://github.com/haskell-unordered-containers/unordered-containers

synopsis:             Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.

    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.

category:             Data
abi:                  6cef23d5a75aa770de48efbb6204a2ab
exposed:              True
exposed-modules:
    Data.HashMap.Internal Data.HashMap.Internal.Array
    Data.HashMap.Internal.List Data.HashMap.Internal.Strict
    Data.HashMap.Internal.Unsafe Data.HashMap.Lazy Data.HashMap.Strict
    Data.HashSet Data.HashSet.Internal

import-dirs:
    /usr/lib/ghc-8.10.2/site-local/unordered-containers-0.2.12.0

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/unordered-containers-0.2.12.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/unordered-containers-0.2.12.0

hs-libraries:         HSunordered-containers-0.2.12.0-JMHeBencosjFi5kYThmmhW
depends:
    base-4.14.1.0 deepseq-1.4.4.0
    hashable-1.3.0.0-JdGAj1lGWBF8rPo7OULhuw

haddock-interfaces:
    /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
